@@ -3,7 +3,6 @@ import tensorflow as tf
 from kgcnn.ops.casting import kgcnn_ops_dyn_cast
 from kgcnn.ops.partition import kgcnn_ops_change_partition_type
 from kgcnn.ops.ragged import DummyRankOneRaggedTensor
-from kgcnn.ops.types import kgcnn_ops_static_test_tensor_input_type
 
 
 class GraphBaseLayer(tf.keras.layers.Layer):
@@ -55,14 +54,36 @@ class GraphBaseLayer(tf.keras.layers.Layer):
                                                "tensor", "RaggedTensor", "Tensor"]
 
         self._tensor_input_type_found = []
-        self._test_tensor_input = kgcnn_ops_static_test_tensor_input_type(self.input_tensor_type,
-                                                                          self._tensor_input_type_implemented,
-                                                                          self.node_indexing)
+        self._test_tensor_input = self._kgcnn_static_tensor_input_check()
 
-        self._all_kgcnn_info = {"node_indexing": self.node_indexing, "partition_type": self.partition_type,
-                                "input_tensor_type": self.input_tensor_type, "ragged_validate": self.ragged_validate,
-                                "is_sorted": self.is_sorted, "has_unconnected": self.has_unconnected,
-                                "output_tensor_type": self.output_tensor_type, "is_directed": self.is_directed}
+        self._kgcnn_info = {"node_indexing": self.node_indexing, "partition_type": self.partition_type,
+                            "input_tensor_type": self.input_tensor_type, "ragged_validate": self.ragged_validate,
+                            "is_sorted": self.is_sorted, "has_unconnected": self.has_unconnected,
+                            "output_tensor_type": self.output_tensor_type, "is_directed": self.is_directed}
+
+    def _kgcnn_static_tensor_input_check(self):
+
+        tensor_keys = ["Tensor", "tensor"]
+        ragged_keys = ["ragged", "RaggedTensor"]
+        value_partition_keys = ["disjoint", "values_partition"]
+
+        if self.input_tensor_type not in self._tensor_input_type_implemented:
+            raise NotImplementedError("Error: Tensor input type ", self.input_tensor_type,
+                                      "is not implemented for",self.name,", choose one of the following:",
+                                      self._tensor_input_type_implemented)
+        if self.node_indexing is not None:
+            if self.input_tensor_type in ragged_keys and self.node_indexing not in ["sample"]:
+                print("Warning: For ragged tensor input, default node_indexing is considered 'sample'.",
+                      self.name,"will use node_indexing", self.node_indexing)
+
+            if self.input_tensor_type in value_partition_keys and self.node_indexing not in ["batch", "disjoint"]:
+                print("Warning: For [values, partition] tensor input, default n"
+                      "ode_indexing is considered 'batch'.",self.name,
+                      "will use node_indexing", self.node_indexing)
+
+            if self.input_tensor_type in tensor_keys and self.node_indexing not in ["sample"]:
+                print("Warning: For tensor input, default node_indexing is considered 'sample'.",self.name,
+                      "will use node_indexing", self.node_indexing)
 
     def get_config(self):
         config = super(GraphBaseLayer, self).get_config()
@@ -77,6 +98,7 @@ class GraphBaseLayer(tf.keras.layers.Layer):
                        })
         return config
 
+
     def _kgcnn_map_input_ragged(self, inputs, num_input):
         """Flexible input tensor check.
 
@@ -167,20 +189,21 @@ class GraphBaseLayer(tf.keras.layers.Layer):
             raise TypeError("Error:", self.name, "input type for ragged-like input is not supported for", x)
 
 
-
-
-
-
-
-class KerasLayerWrapperBase(tf.keras.layers.Layer):
-    """Base layer for keras wrapper in kgcnn that allows for ragged input type.
+class KerasWrapperBaseLayer(tf.keras.layers.Layer):
+    """Base layer for keras wrapper in kgcnn that allows for ragged input type with ragged_rank=1.
 
     Args:
+        node_indexing (str): Indices referring to 'sample' or to the continuous 'batch'.
+            For disjoint representation 'batch' is default.
         partition_type (str): Partition tensor type to assign nodes or edges to batch. Default is "row_length".
             This is used for input_tensor_type="values_partition".
         input_tensor_type (str): Input type of the tensors for call(). Default is "ragged".
         output_tensor_type (str): Output type of the tensors for call(). Default is "ragged".
         ragged_validate (bool): Whether to validate ragged tensor. Default is False.
+        is_sorted (bool): If the edge indices are sorted for first ingoing index. Default is False.
+        has_unconnected (bool): If unconnected nodes are allowed. Default is True.
+        is_directed (bool): If the graph can be considered directed. Default is True.
+            This parameter is not used atm but can be useful for expensive edge computation.
     """
 
     def __init__(self,
@@ -188,10 +211,16 @@ class KerasLayerWrapperBase(tf.keras.layers.Layer):
                  input_tensor_type="ragged",
                  output_tensor_type=None,
                  ragged_validate=False,
+                 node_indexing="sample",
+                 is_sorted=False,
+                 has_unconnected=True,
+                 is_directed=True,
                  **kwargs):
         """Initialize layer."""
-        super(KerasLayerWrapperBase, self).__init__(**kwargs)
+        super(KerasWrapperBaseLayer, self).__init__(**kwargs)
 
+        self.is_directed = is_directed
+        self.node_indexing = node_indexing
         self.partition_type = partition_type
         self.input_tensor_type = input_tensor_type
         if output_tensor_type is None:
@@ -199,69 +228,92 @@ class KerasLayerWrapperBase(tf.keras.layers.Layer):
         else:
             self.output_tensor_type = output_tensor_type
         self.ragged_validate = ragged_validate
+        self.is_sorted = is_sorted
+        self.has_unconnected = has_unconnected
         self._supports_ragged_inputs = True
 
         self._tensor_input_type_implemented = ["ragged", "values_partition", "disjoint",
                                                "tensor", "RaggedTensor", "Tensor"]
 
+        self._kgcnn_info = {"node_indexing": self.node_indexing, "partition_type": self.partition_type,
+                            "input_tensor_type": self.input_tensor_type, "ragged_validate": self.ragged_validate,
+                            "is_sorted": self.is_sorted, "has_unconnected": self.has_unconnected,
+                            "output_tensor_type": self.output_tensor_type, "is_directed": self.is_directed}
+
         self._kgcnn_wrapper_call_type = 0
         self._kgcnn_wrapper_args = []
         self._kgcnn_wrapper_layer = None
 
     def call(self, inputs, **kwargs):
+        # Get a single tensor
         if self._kgcnn_wrapper_call_type == 0:
-            # get a single tensor
             if isinstance(inputs, tf.RaggedTensor):
                 if self.input_tensor_type not in ["ragged", "RaggedTensor"]:
-                    print("Warning: Received RaggedTensor but tensor type specified as:", self.input_tensor_type)
-                # Can work already with RaggedTensor
-                # out = self._kgcnn_wrapper_layer(inputs, **kwargs)
-                # We need a check of ragged rank here and default to standard layer
-                value_tensor = inputs.values
-                out_tensor = self._kgcnn_wrapper_layer(value_tensor, **kwargs)
-                return tf.RaggedTensor.from_row_splits(out_tensor, inputs.row_splits, validate=self.ragged_validate)
+                    print("Warning:", self.name, "received RaggedTensor but tensor type specified as:",
+                          self.input_tensor_type)
+                if inputs.ragged_rank == 1:
+                    value_tensor = inputs.values
+                    out_tensor = self._kgcnn_wrapper_layer(value_tensor, **kwargs)
+                    return tf.RaggedTensor.from_row_splits(out_tensor, inputs.row_splits, validate=self.ragged_validate)
+                else:
+                    print("Warning:", self.name, " got tf.RaggedTensor with ragged_rank != 1. Fallback ...")
+                    return self._kgcnn_wrapper_layer(inputs, **kwargs)
             elif isinstance(inputs, list):
                 if self.input_tensor_type not in ["disjoint", "values_partition"]:
-                    print("Warning: Received input list but tensor type specified as:", self.input_tensor_type)
+                    print("Warning:", self.name, "received input list but tensor type specified as:",
+                          self.input_tensor_type)
                 out = self._kgcnn_wrapper_layer(inputs[0], **kwargs)
                 return [out] + inputs[1:]
             elif isinstance(inputs, tf.Tensor):
                 if self.input_tensor_type not in ["Tensor", "tensor"]:
-                    print("Warning: Received Tensor but tensor type specified as:", self.input_tensor_type)
+                    print("Warning:", self.name, "received Tensor but tensor type specified as:",
+                          self.input_tensor_type)
                 return self._kgcnn_wrapper_layer(inputs, **kwargs)
             else:
                 raise NotImplementedError("Error: Unsupported tensor input type of ", inputs)
+
+        # Get a list of tensors
         elif self._kgcnn_wrapper_call_type == 1:
-            # Get a list of tensors
             if isinstance(inputs[0], tf.RaggedTensor):
                 if self.input_tensor_type not in ["ragged", "RaggedTensor"]:
-                    print("Warning: Received RaggedTensor but tensor type specified as:", self.input_tensor_type)
-                # Works already with RaggedTensor but much much slower
-                # out = self._layer_keras(inputs, **kwargs)
-                # We need a check of ragged rank here and default to standard layer
-                out = self._kgcnn_wrapper_layer([x.values for x in inputs], **kwargs)
-                out = tf.RaggedTensor.from_row_splits(out, inputs[0].row_splits, validate=self.ragged_validate)
-                return out
+                    print("Warning:", self.name, "received RaggedTensor but tensor type specified as:",
+                          self.input_tensor_type)
+                if inputs[0].ragged_rank == 1:
+                    out = self._kgcnn_wrapper_layer([x.values for x in inputs], **kwargs)
+                    out = tf.RaggedTensor.from_row_splits(out, inputs[0].row_splits, validate=self.ragged_validate)
+                    return out
+                else:
+                    print("Warning:", self.name, "got tf.RaggedTensor with ragged_rank != 1. Fallback ...")
+                    return self._kgcnn_wrapper_layer(inputs, **kwargs)
             elif isinstance(inputs[0], list):
                 if self.input_tensor_type not in ["disjoint", "values_partition"]:
-                    print("Warning: Received input list but tensor type specified as:", self.input_tensor_type)
+                    print("Warning:", self.name, "received input list but tensor type specified as:",
+                          self.input_tensor_type)
                 out_part = inputs[0][1:]
                 out = self._kgcnn_wrapper_layer([x[0] for x in inputs], **kwargs)
                 return [out] + out_part
             elif isinstance(inputs[0], tf.Tensor):
                 if self.input_tensor_type not in ["Tensor", "tensor"]:
-                    print("Warning: Received Tensor but tensor type specified as:", self.input_tensor_type)
+                    print("Warning:", self.name, "received Tensor but tensor type specified as:",
+                          self.input_tensor_type)
                 return self._kgcnn_wrapper_layer(inputs, **kwargs)
             else:
                 raise NotImplementedError("Error: Unsupported tensor input type of ", inputs)
 
     def get_config(self):
-        config = super(KerasLayerWrapperBase, self).get_config()
-        config.update({"input_tensor_type": self.input_tensor_type, "ragged_validate": self.ragged_validate,
-                       "output_tensor_type": self.output_tensor_type})
+        config = super(KerasWrapperBaseLayer, self).get_config()
+        config.update({"node_indexing": self.node_indexing,
+                       "partition_type": self.partition_type,
+                       "input_tensor_type": self.input_tensor_type,
+                       "ragged_validate": self.ragged_validate,
+                       "is_sorted": self.is_sorted,
+                       "has_unconnected": self.has_unconnected,
+                       "output_tensor_type": self.output_tensor_type,
+                       "is_directed": self.is_directed
+                       })
         if self._kgcnn_wrapper_layer is not None:
             layer_conf = self._kgcnn_wrapper_layer.get_config()
             for x in self._kgcnn_wrapper_args:
-                config.update({x: layer_conf[x]})
+                if x in layer_conf:
+                    config.update({x: layer_conf[x]})
         return config
-
