@@ -4,6 +4,7 @@ from kgcnn.layers.base import GraphBaseLayer
 from kgcnn.ops.partition import kgcnn_ops_change_edge_tensor_indexing_by_row_partition
 
 
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='GatherNodes')
 class GatherNodes(GraphBaseLayer):
     """Gather nodes by node indices.
 
@@ -61,6 +62,7 @@ class GatherNodes(GraphBaseLayer):
         return config
 
 
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='GatherNodesOutgoing')
 class GatherNodesOutgoing(GraphBaseLayer):
     """Gather nodes by indices.
 
@@ -112,6 +114,7 @@ class GatherNodesOutgoing(GraphBaseLayer):
         return config
 
 
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='GatherNodesIngoing')
 class GatherNodesIngoing(GraphBaseLayer):
     """Gather nodes by edge edge_indices.
     
@@ -163,6 +166,7 @@ class GatherNodesIngoing(GraphBaseLayer):
         return config
 
 
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='GatherState')
 class GatherState(GraphBaseLayer):
     """Layer to repeat environment or global state for node or edge lists.
     
