@@ -1,9 +1,10 @@
 import tensorflow as tf
 import tensorflow.keras as ks
 
-from kgcnn.layers.base import KerasLayerWrapperBase
+from kgcnn.layers.base import KerasWrapperBaseLayer
 
-class Dense(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='Dense')
+class Dense(KerasWrapperBaseLayer):
     """Dense Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self,
@@ -34,7 +35,8 @@ class Dense(KerasLayerWrapperBase):
                                                     bias_constraint=bias_constraint)
 
 
-class Activation(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='Activation')
+class Activation(KerasWrapperBaseLayer):
     """Activation Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self,
@@ -49,7 +51,8 @@ class Activation(KerasLayerWrapperBase):
                                                                activity_regularizer=activity_regularizer)
 
 
-class Add(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='Add')
+class Add(KerasWrapperBaseLayer):
     """Add Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self, **kwargs):
@@ -60,7 +63,8 @@ class Add(KerasLayerWrapperBase):
         self._kgcnn_wrapper_layer = ks.layers.Add()
 
 
-class Average(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='Average')
+class Average(KerasWrapperBaseLayer):
     """Average Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self, **kwargs):
@@ -71,7 +75,8 @@ class Average(KerasLayerWrapperBase):
         self._kgcnn_wrapper_layer = ks.layers.Average()
 
 
-class Multiply(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='Multiply')
+class Multiply(KerasWrapperBaseLayer):
     """Multiply Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self, **kwargs):
@@ -82,7 +87,8 @@ class Multiply(KerasLayerWrapperBase):
         self._kgcnn_wrapper_layer = ks.layers.Multiply()
 
 
-class Concatenate(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='Concatenate')
+class Concatenate(KerasWrapperBaseLayer):
     """Concatenate Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self,
@@ -95,7 +101,8 @@ class Concatenate(KerasLayerWrapperBase):
         self._kgcnn_wrapper_layer = ks.layers.Concatenate(axis=axis)
 
 
-class Dropout(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='Dropout')
+class Dropout(KerasWrapperBaseLayer):
     """Dropout Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self,
@@ -110,7 +117,8 @@ class Dropout(KerasLayerWrapperBase):
         self._kgcnn_wrapper_layer = ks.layers.Dropout(rate=rate, noise_shape=noise_shape, seed=seed)
 
 
-class LayerNormalization(KerasLayerWrapperBase):
+@tf.keras.utils.register_keras_serializable(package='kgcnn',name='LayerNormalization')
+class LayerNormalization(KerasWrapperBaseLayer):
     """LayerNormalization Wrapper Layer to support RaggedTensor input with ragged-rank=1."""
 
     def __init__(self,
