@@ -21,13 +21,13 @@ def make_dimnet_pp(
         # Output
         output_embedd: dict = None,
         # Model specific parameter
-        emb_size = 10,
-        out_emb_size = 10,
-        int_emb_size = 10,
-        basis_emb_size =10,
-        num_blocks = 2,
-        num_spherical = 4,
-        num_radial= 3,
+        emb_size = 128,
+        out_emb_size = 256,
+        int_emb_size = 64,
+        basis_emb_size =8,
+        num_blocks = 4,
+        num_spherical = 7,
+        num_radial= 6,
         cutoff=5.0,
         envelope_exponent=5,
         num_before_skip=1,
@@ -50,7 +50,6 @@ def make_dimnet_pp(
     x = xyz_input
     edi = bond_index_input
     adi = angle_index_input
-    print("Warning: DimNet implementation is not sufficiently tested.")
 
     # Calculate distances
     d = NodeDistance()([x, edi])
@@ -75,7 +74,7 @@ def make_dimnet_pp(
         x = DimNetInteractionPPBlock(emb_size, int_emb_size, basis_emb_size, num_before_skip, num_after_skip)(
             [x, rbf, sbf, adi])
         p_update = DimNetOutputBlock(emb_size, out_emb_size, num_dense_output, num_targets=num_targets,
-                                     output_kernel_initializer=output_init)([n, x, rbf, adi])
+                                     output_kernel_initializer=output_init)([n, x, rbf, edi])
         ps = add_xp([ps, p_update])
 
     if extensive:
